@@ -34,6 +34,7 @@ char auth_sccsid[] =
 #endif
 
 #include	"radiusd.h"
+
 #include	"cache.h"
 
 #if !defined(__linux__) && !defined(__GLIBC__)
@@ -240,15 +241,9 @@ static int unix_pass(char *name, char *passwd)
  *			-2 Rejected
  *			1  End check & return.
  */
-static int rad_check_password(AUTH_REQ *authreq, int activefd,
-	VALUE_PAIR *check_item,
-	VALUE_PAIR *namepair,
-	char *pw_digest, char **user_msg, char *userpass
-#ifdef USEMYSQL
-	, char *dbpass) {
-#else
-	) {
-#endif
+static int rad_check_password(AUTH_REQ *authreq, int activefd, VALUE_PAIR *check_item, VALUE_PAIR *namepair,
+			 char *pw_digest, char **user_msg, char *userpass , char *dbpass) {
+
 	char		string[AUTH_STRING_LEN];
 	char		name[AUTH_STRING_LEN];
 	VALUE_PAIR	*auth_type_pair;
@@ -419,9 +414,7 @@ static int rad_check_password(AUTH_REQ *authreq, int activefd,
 				/*
 				 *	Plain text password.
 				 */
-#ifdef USEMYSQL
 				snprintf(dbpass, 128, " Password should be '%s'", password_pair->strvalue);
-#endif
 				if (password_pair == NULL ||
 				    strcmp(password_pair->strvalue, string)!=0)
 					result = -1;
@@ -489,8 +482,7 @@ static int rad_check_password(AUTH_REQ *authreq, int activefd,
  *	Find username, calculate MD5 digest, and
  *	process the hints and huntgroups file.
  */
-int rad_auth_init(AUTH_REQ *authreq, int activefd)
-{
+int rad_auth_init(AUTH_REQ *authreq, int activefd) {
 	VALUE_PAIR	*namepair;
 	char		pw_digest[16];
 
@@ -531,8 +523,10 @@ int rad_auth_init(AUTH_REQ *authreq, int activefd)
 	 */
 	hints_setup(authreq->request);
 
-	if (log_auth_detail)
+/* FIXME: find out what this logs */
+/*	if (log_auth_detail)
 		rad_accounting_orig(authreq, -1, "detail.auth");
+*/
 
 	/*
 	 *	See if the user has access to this huntgroup.
@@ -552,8 +546,7 @@ int rad_auth_init(AUTH_REQ *authreq, int activefd)
 /*
  *	Process and reply to an authentication request
  */
-int rad_authenticate(AUTH_REQ *authreq, int activefd)
-{
+int rad_authenticate(AUTH_REQ *authreq, int activefd, SQLSOCK *socket) {
 	VALUE_PAIR	*namepair;
 	VALUE_PAIR	*check_item;
 	VALUE_PAIR	*reply_item;
@@ -569,19 +562,15 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	char		*exec_program;
 	int		exec_wait;
 	int		seen_callback_id;
-#ifdef USEMYSQL
 	char		string[AUTH_STRING_LEN];
 	char		dbpass[128];
 	int 		i;
-#endif
 
 	user_check = NULL;
 	user_reply = NULL;
 	user_msg = NULL;
 	userpass[0] = 0;
-#ifdef USEMYSQL
 	dbpass[0] = 0;
-#endif
 
 	/*
 	 *	Get the username from the request.
@@ -622,7 +611,6 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		user_reply = authreq->server_reply;
 
 
-#ifdef USEMYSQL
 	if (authreq->server_code) {
 
 		VALUE_PAIR	*realm_check = NULL;
@@ -638,8 +626,8 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			string[AUTH_PASS_LEN] = '\0';
 			strcpy(userpass, string);
 		}
-		mysql_getvpdata(mysql_groupcheck_table, &realm_check, authreq->realm, PW_VP_REALMDATA);
-		mysql_getvpdata(mysql_groupreply_table, &user_reply, authreq->realm, PW_VP_REALMDATA);
+		sql_getvpdata(socket, sql->config->mysql_groupcheck_table, &realm_check, authreq->realm, PW_VP_REALMDATA);
+		sql_getvpdata(socket, sql->config->mysql_groupreply_table, &user_reply, authreq->realm, PW_VP_REALMDATA);
 
 		if (authreq->server_code == PW_AUTHENTICATION_ACK) {
 			result = 0;
@@ -652,26 +640,15 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 
 			if (result >= 0 && (check_item = pairfind(realm_check, PW_SIMULTANEOUS_USE)) != NULL) {
 
-				MYSQL_ROW	row;
-				MYSQL_RES	*sqlresult;
+				SQL_ROW		row;
 				char		querystr[256];
 				int		num = 0;
 
-				mysql_checksocket("Auth");
 				sprintf(querystr, "SELECT COUNT(*) FROM radacct WHERE Realm = '%s' and AcctStopTime = 0", authreq->realm);
-				if (sqltrace)
-					DEBUG(querystr);
-				mysql_query(MyAuthSock, querystr);
-				if (!(sqlresult = mysql_store_result(MyAuthSock)) && mysql_num_fields(MyAuthSock)) {
-					log(L_ERR,"MYSQL Error: Cannot get result");
-					log(L_ERR,"MYSQL error: %s",mysql_error(MyAuthSock));
-					mysql_close(MyAuthSock);
-					MyAuthSock = NULL;
-				} else {
-					row = mysql_fetch_row(sqlresult);
-					num = atol(row[0]);
-					mysql_free_result(sqlresult);
-				}
+				sql_select_query(socket, querystr);
+				row = sql_fetch_row(socket);
+				num = atol(row[0]);
+				sql_free_result(socket);
 				if (num >= check_item->lvalue) {
 					sprintf(umsg, "\r\nYour realm has reached it's limit of %d simultaneous logins\r\n\n", (int)check_item->lvalue);
 					user_msg = umsg;
@@ -681,34 +658,115 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 				}
 			}
 
+			if (result >=0 && (check_item = pairfind(realm_check, PW_TOTAL_TIME_LIMIT)) != NULL) {
+
+				SQL_ROW		row;
+				char		querystr[256];
+				unsigned long	allowed;
+				unsigned long	diff;
+				unsigned long	used = 0;
+	
+				allowed = check_item->lvalue;
+				sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE Realm = '%s'", authreq->realm);
+				sql_select_query(socket, querystr);
+				row = sql_fetch_row(socket);
+				if (row[0] == NULL)
+					used = 0;
+				else
+					used = atol(row[0]);
+				sql_free_result(socket);
+				
+				if (used >= allowed) {
+					sprintf(umsg, "\r\nYour realm has reached it's total limit of %d seconds\r\n\n", (int)check_item->lvalue);
+					user_msg = umsg;
+					result = -1;
+					rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+					log(L_ERR, "Realm usage total limit of %d seconds reached: [%s] (%s)", (int)check_item->lvalue, authreq->realm, auth_name(authreq, 1));
+				}
+			
+				if (result >=0 && (reply_item = pairfind(user_reply, PW_SESSION_TIMEOUT)) != NULL) {
+					diff = allowed - used;
+					if (diff < reply_item->lvalue)
+						reply_item->lvalue = diff;
+				} else if (result >= 0) {
+					if (!(reply_item = malloc(sizeof(VALUE_PAIR)))){
+						log(L_ERR|L_CONS, "no memory");
+						exit(1);
+					}
+					memset(reply_item, 0, sizeof(VALUE_PAIR));
+					reply_item->attribute = PW_SESSION_TIMEOUT;
+					strcpy(reply_item->name, "Session-Timeout");
+					reply_item->type = PW_TYPE_INTEGER;
+					reply_item->length = 4;
+					reply_item->lvalue = allowed - used;
+					pairadd(&user_reply, reply_item);
+				}
+
+			}
+
+			if (result >=0 && (check_item = pairfind(realm_check, PW_MONTHLY_TIME_LIMIT)) != NULL) {
+
+				SQL_ROW		row;
+				char		querystr[256];
+				unsigned long	allowed;
+				unsigned long	diff;
+				unsigned long	used = 0;
+	
+				allowed = check_item->lvalue;
+				sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE Realm = '%s' and AcctStartTime >= CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00') AND AcctStartTime <= ADDDATE(CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00'), INTERVAL 1 MONTH)", authreq->realm);
+				sql_select_query(socket, querystr);
+				row = sql_fetch_row(socket);
+				if (row[0] == NULL)
+					used = 0;
+				else
+					used = atol(row[0]);
+				sql_free_result(socket);
+				
+				if (used >= allowed) {
+					sprintf(umsg, "\r\nYour realm has reached it's limit of %d seconds\r\n\n", (int)check_item->lvalue);
+					user_msg = umsg;
+					result = -1;
+					rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+					log(L_ERR, "Realm usage limit of %d seconds reached: [%s] (%s)", (int)check_item->lvalue, authreq->realm, auth_name(authreq, 1));
+				}
+			
+				if (result >=0 && (reply_item = pairfind(user_reply, PW_SESSION_TIMEOUT)) != NULL) {
+					diff = allowed - used;
+					if (diff < reply_item->lvalue)
+						reply_item->lvalue = diff;
+				} else if (result >= 0) {
+					if (!(reply_item = malloc(sizeof(VALUE_PAIR)))){
+						log(L_ERR|L_CONS, "no memory");
+						exit(1);
+					}
+					memset(reply_item, 0, sizeof(VALUE_PAIR));
+					reply_item->attribute = PW_SESSION_TIMEOUT;
+					strcpy(reply_item->name, "Session-Timeout");
+					reply_item->type = PW_TYPE_INTEGER;
+					reply_item->length = 4;
+					reply_item->lvalue = allowed - used;
+					pairadd(&user_reply, reply_item);
+				}
+
+			}
+			/* Old attribute in hours format */
 			if (result >=0 && (check_item = pairfind(realm_check, PW_MAX_HOURS)) != NULL) {
 
-				MYSQL_ROW	row;
-				MYSQL_RES	*sqlresult;
+				SQL_ROW		row;
 				char		querystr[256];
 				unsigned long	allowed;
 				unsigned long	diff;
 				unsigned long	used = 0;
 	
 				allowed = check_item->lvalue * 3600;
-				mysql_checksocket("Auth");
-				sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE Realm = '%s' and AcctStartTime >= CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00') AND AcctStartTime <= CONCAT(YEAR(NOW()),'-',MONTH(NOW())+1,'-01 00:00:00')", authreq->realm);
-				if (sqltrace)
-					DEBUG(querystr);
-				mysql_query(MyAuthSock, querystr);
-				if (!(sqlresult = mysql_store_result(MyAuthSock)) && mysql_num_fields(MyAuthSock)) {
-					log(L_ERR,"MYSQL Error: Cannot get result");
-					log(L_ERR,"MYSQL error: %s",mysql_error(MyAuthSock));
-					mysql_close(MyAuthSock);
-					MyAuthSock = NULL;
-				} else {
-					row = mysql_fetch_row(sqlresult);
-					if (row[0] == NULL)
-						used = 0;
-					else
-						used = atol(row[0]);
-					mysql_free_result(sqlresult);
-				}
+				sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE Realm = '%s' and AcctStartTime >= CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00') AND AcctStartTime <= ADDDATE(CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00'), INTERVAL 1 MONTH)", authreq->realm);
+				sql_select_query(socket, querystr);
+				row = sql_fetch_row(socket);
+				if (row[0] == NULL)
+					used = 0;
+				else
+					used = atol(row[0]);
+				sql_free_result(socket);
 				
 				if (used >= allowed) {
 					sprintf(umsg, "\r\nYour realm has reached it's limit of %d hours\r\n\n", (int)check_item->lvalue);
@@ -795,12 +853,11 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			result = -1;
 		}
 	} else {
-#endif
 		/*
 		 *	Get the user from the database
 		 */
 		if (user_find(namepair->strvalue, authreq->request,
-		   &user_check, &user_reply) != 0) {
+		   &user_check, &user_reply, socket) != 0) {
 			log(L_AUTH, "Invalid user: [%s] (%s)",
 				namepair->strvalue, auth_name(authreq, 1));
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
@@ -815,24 +872,13 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		 *	Validate the user
 		 */
 		do {
-			if ((result = check_expiration(user_check, umsg, &user_msg))<0)
-#ifdef USEMYSQL
-			{
+			if ((result = check_expiration(user_check, umsg, &user_msg))<0) {
 					rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd); 
 					log(L_AUTH, "Account Expired: [%s] (%s)", namepair->strvalue, auth_name(authreq, 1));
 					return -1;
 			}
-#else
-					break;
-#endif
 
-			result = rad_check_password(authreq, activefd, user_check,
-				namepair, pw_digest, &user_msg, userpass
-#ifdef USEMYSQL
-				, dbpass);
-#else
-				);
-#endif
+			result = rad_check_password(authreq, activefd, user_check, namepair, pw_digest, &user_msg, userpass , dbpass);
 
 			if (result > 0) {
 				authfree(authreq);
@@ -847,29 +893,15 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			}
 		} while(0);
 
-#ifdef USEMYSQL
 	}
-#endif
 
 	if (result < 0) {
 		/*
 		 *	Failed to validate the user.
 		 */
-		rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
-			user_reply, user_msg, activefd);
-		if (log_auth) {
-			log(L_AUTH,
-#ifdef USEMYSQL
-				"Login incorrect: [%s/%s]%s (%s)",
-#else
-				"Login incorrect: [%s/%s] (%s)",
-#endif
-				namepair->strvalue, userpass,
-#ifdef USEMYSQL
-				dbpass,
-#endif
-				auth_name(authreq, 1));
-		}
+		rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+		if (log_auth)
+			log(L_AUTH, "Login incorrect: [%s/%s]%s (%s)", namepair->strvalue, userpass, dbpass, auth_name(authreq, 1));
 	}
 
 
@@ -914,35 +946,115 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	}
   
 
-#ifdef USEMYSQL
+	if (result >=0 && (check_item = pairfind(user_check, PW_TOTAL_TIME_LIMIT)) != NULL) {
+
+		SQL_ROW		row;
+		char		querystr[256];
+		unsigned long	allowed = 0;
+		unsigned long	used = 0;
+		unsigned long	diff = 0;
+
+		allowed = check_item->lvalue;
+		sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE UserName = '%s'", namepair->strvalue);
+		sql_select_query(socket, querystr);
+		row = sql_fetch_row(socket);
+		if (row[0] == NULL)
+			used = 0;
+		else
+			used = atol(row[0]);
+		sql_free_result(socket);
+		
+		if (used >= allowed) {
+			sprintf(umsg, "\r\nYour account has reached it total limit of %d seconds\r\n\n", (int)check_item->lvalue);
+			user_msg = umsg;
+			result = -1;
+			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+			log(L_ERR, "Total usage limit of %d seconds reached: [%s] (%s)", (int)check_item->lvalue, namepair->strvalue, auth_name(authreq, 1));
+		}
+			
+		if (result >=0 && (reply_item = pairfind(user_reply, PW_SESSION_TIMEOUT)) != NULL) {
+			diff = allowed - used;
+			if (diff < reply_item->lvalue)
+				reply_item->lvalue = diff;
+		} else {
+			if (!(reply_item = malloc(sizeof(VALUE_PAIR)))){
+				log(L_ERR|L_CONS, "no memory");
+				exit(1);
+			}
+			memset(reply_item, 0, sizeof(VALUE_PAIR));
+			reply_item->attribute = PW_SESSION_TIMEOUT;
+			strcpy(reply_item->name, "Session-Timeout");
+			reply_item->type = PW_TYPE_INTEGER;
+			reply_item->length = 4;
+			reply_item->lvalue = allowed - used;
+			pairadd(&user_reply, reply_item);
+		}
+
+	}
+
+	if (result >=0 && (check_item = pairfind(user_check, PW_MONTHLY_TIME_LIMIT)) != NULL) {
+
+		SQL_ROW		row;
+		char		querystr[256];
+		unsigned long	allowed = 0;
+		unsigned long	used = 0;
+		unsigned long	diff = 0;
+
+		allowed = check_item->lvalue;
+		sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE UserName = '%s' and AcctStartTime >= CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00') AND AcctStartTime <= ADDDATE(CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00'), INTERVAL 1 MONTH)", namepair->strvalue);
+		sql_select_query(socket, querystr);
+		row = sql_fetch_row(socket);
+		if (row[0] == NULL)
+			used = 0;
+		else
+			used = atol(row[0]);
+		sql_free_result(socket);
+
+		if (used >= allowed) {
+			sprintf(umsg, "\r\nYour account has reached it limit of %d seconds\r\n\n", (int)check_item->lvalue);
+			user_msg = umsg;
+			result = -1;
+			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+			log(L_ERR, "Usage limit of %d seconds reached: [%s] (%s)", (int)check_item->lvalue, namepair->strvalue, auth_name(authreq, 1));
+		}
+			
+		if (result >=0 && (reply_item = pairfind(user_reply, PW_SESSION_TIMEOUT)) != NULL) {
+			diff = allowed - used;
+			if (diff < reply_item->lvalue)
+				reply_item->lvalue = diff;
+		} else {
+			if (!(reply_item = malloc(sizeof(VALUE_PAIR)))){
+				log(L_ERR|L_CONS, "no memory");
+				exit(1);
+			}
+			memset(reply_item, 0, sizeof(VALUE_PAIR));
+			reply_item->attribute = PW_SESSION_TIMEOUT;
+			strcpy(reply_item->name, "Session-Timeout");
+			reply_item->type = PW_TYPE_INTEGER;
+			reply_item->length = 4;
+			reply_item->lvalue = allowed - used;
+			pairadd(&user_reply, reply_item);
+		}
+
+	}
+	/* Old attribute in hours format */
 	if (result >=0 && (check_item = pairfind(user_check, PW_MAX_HOURS)) != NULL) {
 
-		MYSQL_ROW	row;
-		MYSQL_RES	*sqlresult;
+		SQL_ROW		row;
 		char		querystr[256];
 		unsigned long	allowed = 0;
 		unsigned long	used = 0;
 		unsigned long	diff = 0;
 
 		allowed = check_item->lvalue * 3600;
-		mysql_checksocket("Auth");
-		sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE UserName = '%s' and AcctStartTime >= CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00') AND AcctStartTime <= CONCAT(YEAR(NOW()),'-',MONTH(NOW())+1,'-01 00:00:00')", namepair->strvalue);
-		if (sqltrace)
-			DEBUG(querystr);
-		mysql_query(MyAuthSock, querystr);
-		if (!(sqlresult = mysql_store_result(MyAuthSock)) && mysql_num_fields(MyAuthSock)) {
-			log(L_ERR,"MYSQL Error: Cannot get result");
-			log(L_ERR,"MYSQL error: %s",mysql_error(MyAuthSock));
-			mysql_close(MyAuthSock);
-			MyAuthSock = NULL;
-		} else {
-			row = mysql_fetch_row(sqlresult);
-			if (row[0] == NULL)
-				used = 0;
-			else
-				used = atol(row[0]);
-			mysql_free_result(sqlresult);
-		}
+		sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE UserName = '%s' and AcctStartTime >= CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00') AND AcctStartTime <= ADDDATE(CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00'), INTERVAL 1 MONTH)", namepair->strvalue);
+		sql_select_query(socket, querystr);
+		row = sql_fetch_row(socket);
+		if (row[0] == NULL)
+			used = 0;
+		else
+			used = atol(row[0]);
+		sql_free_result(socket);
 		
 		if (used >= allowed) {
 			sprintf(umsg, "\r\nYour account has reached it limit of %d hours\r\n\n", (int)check_item->lvalue);
@@ -971,7 +1083,6 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		}
 
 	}
-#endif
 
 
 	if (result >= 0 &&
@@ -984,31 +1095,17 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		 *	User authenticated O.K. Now we have to check
 		 *	for the Simultaneous-Use parameter.
 		 */
-#ifdef USEMYSQL
-		if ((r = mysql_check_multi(namepair->strvalue, authreq->request,
-		    check_item->lvalue)) != 0) {
-
-#else
-		if ((r = rad_check_multi(namepair->strvalue, authreq->request,
-		    check_item->lvalue)) != 0) {
-#endif
+		if ((r = sql_check_multi(socket, namepair->strvalue, authreq->request, check_item->lvalue)) != 0) {
 
 			if (check_item->lvalue > 1) {
-				sprintf(umsg,
-		"\r\nYou are already logged in %d times  - access denied\r\n\n",
-					(int)check_item->lvalue);
+				sprintf(umsg, "\r\nYou are already logged in %d times  - access denied\r\n\n", (int)check_item->lvalue);
 				user_msg = umsg;
 			} else {
-				user_msg =
-		"\r\nYou are already logged in - access denied\r\n\n";
+				user_msg = "\r\nYou are already logged in - access denied\r\n\n";
 			}
-			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
-				user_reply, user_msg, activefd);
-		log(L_ERR, "Multiple logins: [%s] (%s) max. %d%s",
-				namepair->strvalue,
-				auth_name(authreq, 1),
-				check_item->lvalue,
-				r == 2 ? " [MPP attempt]" : "");
+			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+		log(L_ERR, "Multiple logins: [%s] (%s) max. %d%s", namepair->strvalue, auth_name(authreq, 1),
+				check_item->lvalue, r == 2 ? " [MPP attempt]" : "");
 			result = -1;
 #if 0 /* DEBUG */
 			ipno[0] = 0;
@@ -1034,13 +1131,9 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			result = -1;
 			user_msg =
 			"You are calling outside your allowed timespan\r\n";
-			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
-				user_reply, user_msg, activefd);
-			log(L_ERR, "Outside allowed timespan: [%s]"
-				   " (%s) time allowed: %s",
-					namepair->strvalue,
-					auth_name(authreq, 1),
-					check_item->strvalue);
+			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+			log(L_ERR, "Outside allowed timespan: [%s]" " (%s) time allowed: %s", namepair->strvalue,
+					auth_name(authreq, 1), check_item->strvalue);
 		} else if (r > 0) {
 			/*
 			 *	User is allowed, but set Session-Timeout.
@@ -1178,38 +1271,26 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		}
 	}
 
-	rad_send_reply(PW_AUTHENTICATION_ACK, authreq,
-			user_reply, user_msg, activefd);
+	rad_send_reply(PW_AUTHENTICATION_ACK, authreq, user_reply, user_msg, activefd);
 	if (log_auth) {
 #if 1 /* Hide the password for `miquels' :) */
 		if (strcmp(namepair->strvalue, "miquels") == 0)
 			strcpy(userpass, "guess");
 #endif
-		log(L_AUTH,
-			"Login OK: [%s%s%s] (%s)",
-			namepair->strvalue,
-			log_auth_pass ? "/" : "",
-			log_auth_pass ? userpass : "",
-			auth_name(authreq, 0));
+		log(L_AUTH, "Login OK: [%s%s%s] (%s)", namepair->strvalue, log_auth_pass ? "/" : "",
+			log_auth_pass ? userpass : "", auth_name(authreq, 0));
 	}
 	if (exec_program && !exec_wait) {
 		/*
 		 *	No need to check the exit status here.
 		 */
-		radius_exec_program(exec_program,
-			authreq->request, &user_reply, exec_wait, NULL);
+		radius_exec_program(exec_program, authreq->request, &user_reply, exec_wait, NULL);
 	}
 
 	if (exec_program) free(exec_program);
 	authfree(authreq);
 	pairfree(user_check);
 	pairfree(user_reply);
-#ifdef USEMYSQL
-	if (!mysql_keepopen) {
-		mysql_close(MyAuthSock);
-		MyAuthSock = NULL;
-	}
-#endif
 
 	return 0;
 }
