@@ -5,11 +5,6 @@
 #define RADLOG_DIR		"/var/log"
 
 #define RADIUS_DICTIONARY	"dictionary"
-#ifndef USEMYSQL
-#define RADIUS_CLIENTS		"clients"
-#define RADIUS_USERS		"users"
-#endif
-
 #define RADIUS_NASLIST		"naslist"
 #define RADIUS_HOLD		"holdusers"
 #define RADIUS_LOG		"radius.log"
@@ -44,15 +39,17 @@
 #define ASCEND_PORT_HACK
 #define ASCEND_CHANNELS_PER_LINE        23
 
-#ifdef USEMYSQL
-#include <mysql/mysql.h>
+/* SQL defines */
+#define SQL_LOCK_LEN sizeof(MYSQLREC)
+#define MAX_TABLE_LEN 20
+#define MAX_AUTH_QUERY_LEN 256
 #define	QUERYLOG	"/var/log/radacct/radius.sql"
 #define	MYSQLCONFIG	"radius.conf"
 #define	MYSQLBACKUP	"/var/log/radacct/sqlbackup.dat"
 #define SQLBIGREC       32
 #define SQLLILREC       15
 #define MAX_COMMUNITY_LEN 50
-#endif
+#define MAX_SQL_SOCKS	8
 
 /*
  *	Hack for USR gear - uses a different Vendor-Specific attribute
