@@ -65,11 +65,6 @@ static char *months[] = {
 	"Jan", "Feb", "Mar", "Apr", "May", "Jun",
 	"Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
 
-#ifndef USEMYSQL
-PAIR_LIST	*users;
-NAS		*naslist;
-CLIENT		*clients;
-#endif
 PAIR_LIST	*huntgroups;
 PAIR_LIST	*hints;
 REALM		*realms;
@@ -263,7 +258,6 @@ void presuf_setup(VALUE_PAIR *request_pairs)
 	if ((name_pair = pairfind(request_pairs, PW_USER_NAME)) == NULL)
 		return;
 
-#ifdef USEMYSQL
 
 		/*
 		 *	Find Prefix / Suffix.
@@ -282,34 +276,6 @@ void presuf_setup(VALUE_PAIR *request_pairs)
 		strcpy(name_pair->strvalue, name);
 		name_pair->length = strlen(name_pair->strvalue);
 
-#else
-	for (pl = users; pl; pl = pl->next) {
-		/*
-		 *	Matching name?
-		 */
-		if (strncmp(pl->name, "DEFAULT", 7) != 0 &&
-		    strcmp(pl->name, name_pair->strvalue) != 0)
-			continue;
-		/*
-		 *	Find Prefix / Suffix.
-		 */
-		if ((presuf_pair = pairfind(pl->check, PW_PREFIX)) == NULL &&
-		    (presuf_pair = pairfind(pl->check, PW_SUFFIX)) == NULL)
-			continue;
-		if (presufcmp(presuf_pair, name_pair->strvalue, name, sizeof(name)) != 0)
-			continue;
-		/*
-		 *	See if username must be stripped.
-		 */
-		if ((tmp = pairfind(pl->check, PW_STRIP_USERNAME)) != NULL &&
-		    tmp->lvalue == 0)
-			continue;
-		strcpy(name_pair->strvalue, name);
-		name_pair->length = strlen(name_pair->strvalue);
-		break;
-	}
-
-#endif
 }
 
 
@@ -790,30 +756,6 @@ void auth_type_fixup(VALUE_PAIR *check)
 
 }
 
-#ifndef USEMYSQL
-static void pair_sanity(char *fn, PAIR_LIST *entry)
-{
-      VALUE_PAIR *pair;
-
-      for (entry = users; entry; entry = entry->next) {
-              for (pair = entry->reply; pair; pair = pair->next) {
-                      if ((pair->attribute == PW_PASSWORD) ||
-                          (pair->attribute == PW_CHAP_PASSWORD) ||
-                          (pair->attribute >= 1000 &&
-                           pair->attribute <= 65536)) {
-
-              log(L_ERR|L_CONS, "\n[%s:%d] WARNING: Check item \"%s\"\n"
-                  "\tfound in reply item list for user \"%s\".\n"
-                  "\tThis attribute MUST go on the first line"
-                  " with the other check items.\n", fn, entry->lineno,
-                  pair->name, entry->name);
-
-                      }
-              }
-      }
-}	
-#endif
-
 #define FIND_MODE_NAME	0
 #define FIND_MODE_REPLY	1
 
@@ -938,10 +880,6 @@ parse_again:
 					pl = t;
 				last = t;
 
-#ifndef USEMYSQL
-				pair_sanity(file, t);
-#endif
-
 				mode = FIND_MODE_NAME;
 				if (buffer[0] != 0)
 					goto parse_again;
@@ -1041,19 +979,6 @@ static int dbm_find(char *name, VALUE_PAIR *request_pairs,
 }
 #endif /* DBM */
 
-/*
- *	See if a VALUE_PAIR list contains Fall-Through = Yes
- */
-#ifndef USEMYSQL
-static int fallthrough(VALUE_PAIR *vp)
-{
-	VALUE_PAIR *tmp;
-
-	tmp = pairfind(vp, PW_FALL_THROUGH);
-
-	return tmp ? tmp->lvalue : 0;
-}
-#endif
 
 
 #ifdef ASCEND_PORT_HACK
@@ -1087,20 +1012,13 @@ static int ascend_port_number(int nas_port)
  *	needs to check the password, the rest is done here.
  */
 int user_find(char *name, VALUE_PAIR *request_pairs,
-		VALUE_PAIR **check_pairs, VALUE_PAIR **reply_pairs)
+		VALUE_PAIR **check_pairs, VALUE_PAIR **reply_pairs,  SQLSOCK *socket)
 {
 	int		nas_port = 0;
 	VALUE_PAIR	*check_tmp = NULL;
 	VALUE_PAIR	*reply_tmp = NULL;
 	VALUE_PAIR	*tmp;
 	int		found = 0;
-#ifdef USE_DBM
-	int		i, r;
-	char		buffer[256];
-#endif
-#ifndef USEMYSQL
-	PAIR_LIST	*pl;
-#endif
 #ifdef NT_DOMAIN_HACK
 	char		*ptr;
 	char		newname[AUTH_STRING_LEN];
@@ -1139,17 +1057,16 @@ int user_find(char *name, VALUE_PAIR *request_pairs,
 	}
 #endif /* NT_DOMAIN_HACK */
 
-#ifdef USEMYSQL
 
-	if ((found = mysql_getvpdata(mysql_authcheck_table, &check_tmp, name, PW_VP_USERDATA)) > 0) {
-		mysql_getvpdata(mysql_groupcheck_table, &check_tmp, name, PW_VP_GROUPDATA);
-		mysql_getvpdata(mysql_authreply_table, &reply_tmp, name, PW_VP_USERDATA);
-		mysql_getvpdata(mysql_groupreply_table, &reply_tmp, name, PW_VP_GROUPDATA);
+	if ((found = sql_getvpdata(socket, sql->config->mysql_authcheck_table, &check_tmp, name, PW_VP_USERDATA)) > 0) {
+		sql_getvpdata(socket, sql->config->mysql_groupcheck_table, &check_tmp, name, PW_VP_GROUPDATA);
+		sql_getvpdata(socket, sql->config->mysql_authreply_table, &reply_tmp, name, PW_VP_USERDATA);
+		sql_getvpdata(socket, sql->config->mysql_groupreply_table, &reply_tmp, name, PW_VP_GROUPDATA);
 	} else {
 
 		int gcheck, greply;
-		gcheck = mysql_getvpdata(mysql_groupcheck_table, &check_tmp, "DEFAULT", PW_VP_GROUPDATA);
-		greply = mysql_getvpdata(mysql_groupreply_table, &reply_tmp, "DEFAULT", PW_VP_GROUPDATA);
+		gcheck = sql_getvpdata(socket, sql->config->mysql_groupcheck_table, &check_tmp, "DEFAULT", PW_VP_GROUPDATA);
+		greply = sql_getvpdata(socket, sql->config->mysql_groupreply_table, &reply_tmp, "DEFAULT", PW_VP_GROUPDATA);
 		if (gcheck == 0 || greply == 0)
 			return -1;
 	}
@@ -1167,88 +1084,6 @@ int user_find(char *name, VALUE_PAIR *request_pairs,
 	DEBUG("DONE DEBUGGING PAIR LIST\n");
 #endif
 
-#else
-
-#ifdef USE_DBM
-	if (use_dbm) {
-		/*
-		 *	FIXME: No Prefix / Suffix support for DBM.
-		 */
-		sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_USERS);
-#ifdef DBM
-		if (dbminit(buffer) != 0)
-#endif
-#ifdef NDBM
-		if ((dbmfile = dbm_open(buffer, O_RDONLY, 0)) == NULL)
-#endif
-		{
-			log(L_ERR|L_CONS, "cannot open dbm file %s",
-				buffer);
-			return 0;
-		}
-
-		r = dbm_find(name, request_pairs, check_pairs, reply_pairs);
-		if (r > 0) found = 1;
-		if (r <= 0 || fallthrough(*reply_pairs)) {
-
-			pairdelete(reply_pairs, PW_FALL_THROUGH);
-
-			sprintf(buffer, "DEFAULT");
-			i = 0;
-			while ((r = dbm_find(buffer, request_pairs,
-			       check_pairs, reply_pairs)) >= 0 || i < 2) {
-				if (r > 0) {
-					found = 1;
-					if (!fallthrough(*reply_pairs))
-						break;
-					pairdelete(reply_pairs,PW_FALL_THROUGH);
-				}
-				sprintf(buffer, "DEFAULT%d", i++);
-			}
-		}
-#ifdef DBM
-		dbmclose();
-#endif
-#ifdef NDBM
-		dbm_close(dbmfile);
-#endif
-	} else
-	/*
-	 *	Note the fallthrough through the #endif.
-	 */
-#endif
-	for(pl = users; pl; pl = pl->next) {
-		if (strcmp(name, pl->name) && strcmp(pl->name, "DEFAULT"))
-			continue;
-
-		if (paircmp(request_pairs, pl->check) == 0) {
-			DEBUG("  users: Matched %s at %d",
-			       pl->name, pl->lineno);
-			found = 1;
-			check_tmp = paircopy(pl->check);
-			reply_tmp = paircopy(pl->reply);
-			pairmove(reply_pairs, &reply_tmp);
-			pairmove(check_pairs, &check_tmp);
-			pairfree(reply_tmp);
-			pairfree(check_tmp);
-
-			/*
-			 *	Fallthrough?
-			 */
-			if (!fallthrough(pl->reply)) 
-				break; 
-		}
-	}
-
-
-	/*
-	 *	See if we succeeded.
-	 */
-	if (!found)
-		return -1;
-#endif
-
-         
 
 	/*
 	 *	Fix dynamic IP address if needed.
@@ -1274,9 +1109,6 @@ int user_find(char *name, VALUE_PAIR *request_pairs,
 	/*
 	 *	Remove server internal parameters.
 	 */
-#ifndef USEMYSQL
-	pairdelete(reply_pairs, PW_FALL_THROUGH);
-#endif
 
 	return 0;
 }
@@ -1545,31 +1377,17 @@ static int matches(char *name, PAIR_LIST *pl, char *matchpart, int matchlen)
 	if ((tmp = pairfind(pl->check, PW_PREFIX)) != NULL ||
 	    (tmp = pairfind(pl->check, PW_SUFFIX)) != NULL) {
 
-#ifdef USEMYSQL
 		if (strcmp(pl->name, name) == 0)
 			return !presufcmp(tmp, name, matchpart, matchlen);
-#else
-		if (strncmp(pl->name, "DEFAULT", 7) == 0 ||
-		    strcmp(pl->name, name) == 0)
-			return !presufcmp(tmp, name, matchpart, matchlen);
-#endif
 	}
 
 	/*
 	 *	Shortcut if there's no '*' in pl->name.
 	 */
-#ifdef USEMYSQL
 	if (strchr(pl->name, '*') == NULL &&
 	    strcmp(pl->name, name) == 0) {
 		strNcpy(matchpart, name, matchlen);
 		return 1;
-#else
-	if (strchr(pl->name, '*') == NULL &&
-	    (strncmp(pl->name, "DEFAULT", 7) == 0 ||
-	     strcmp(pl->name, name) == 0)) {
-		strNcpy(matchpart, name, matchlen);
-		return 1;
-#endif
 	}
 
 	/*
@@ -1826,61 +1644,6 @@ void clients_free(CLIENT *cl)
 }
 
 
-/*
- *	Read the clients file.
- */
-#ifndef USEMYSQL
-int read_clients_file(char *file)
-{
-	FILE	*fp;
-	char	buffer[256];
-	char	hostnm[128];
-	char	secret[32];
-	char	shortnm[32];
-	int	lineno = 0;
-	CLIENT	*c;
-
-	clients_free(clients);
-	clients = NULL;
-
-	if ((fp = fopen(file, "r")) == NULL) {
-		log(L_CONS|L_ERR, "cannot open %s", file);
-		return -1;
-	}
-	while(fgets(buffer, 256, fp) != NULL) {
-		lineno++;
-		if (buffer[0] == '#' || buffer[0] == '\n')
-			continue;
-
-		shortnm[0] = 0;
-		if (sscanf(buffer, "%127s%31s%31s", hostnm, secret, shortnm) < 2) {
-			log(L_ERR, "%s[%d]: syntax error", file, lineno);
-			continue;
-		}
-		if (shortnm[0] == '#') shortnm[0] = 0;
-
-		if ((c = malloc(sizeof(CLIENT))) == NULL) {
-			log(L_CONS|L_ERR, "%s[%d]: out of memory",
-				file, lineno);
-			return -1;
-		}
-
-		c->ipaddr = get_ipaddr(hostnm);
-		strNcpy(c->secret, secret, sizeof(c->secret));
-		strNcpy(c->shortname, shortnm, sizeof(c->shortname));
-		strNcpy(c->longname, ip_hostname(c->ipaddr),
-			sizeof(c->longname));
-
-		c->next = clients;
-		clients = c;
-	}
-	fclose(fp);
-
-	return 0;
-}
-#endif
-
-
 /*
  *	Find a client in the CLIENTS list.
  */
@@ -1940,123 +1703,6 @@ void realm_free(REALM *cl)
 	}
 }
 
-/*
- *	Read the nas file.
- */
-#ifndef USEMYSQL
-int read_naslist_file(char *file)
-{
-	FILE	*fp;
-	char	buffer[256];
-	char	hostnm[128];
-	char	shortnm[32];
-	char	nastype[32];
-	int	lineno = 0;
-	NAS	*c;
-
-	nas_free(naslist);
-	naslist = NULL;
-
-	if ((fp = fopen(file, "r")) == NULL) {
-		log(L_CONS|L_ERR, "cannot open %s", file);
-		return -1;
-	}
-	while(fgets(buffer, 256, fp) != NULL) {
-		lineno++;
-		if (buffer[0] == '#' || buffer[0] == '\n')
-			continue;
-		nastype[0] = 0;
-		if (sscanf(buffer, "%127s%31s%31s", hostnm, shortnm, nastype) < 2) {
-			log(L_ERR, "%s[%d]: syntax error", file, lineno);
-			continue;
-		}
-		if ((c = malloc(sizeof(NAS))) == NULL) {
-			log(L_CONS|L_ERR, "%s[%d]: out of memory",
-				file, lineno);
-			return -1;
-		}
-
-		c->ipaddr = get_ipaddr(hostnm);
-		strNcpy(c->nastype, nastype, sizeof(c->nastype));
-		strNcpy(c->shortname, shortnm, sizeof(c->shortname));
-		strNcpy(c->longname, ip_hostname(c->ipaddr),
-			sizeof(c->longname));
-
-		c->next = naslist;
-		naslist = c;
-	}
-	fclose(fp);
-
-	return 0;
-}
-#endif
-
-/*
- *	Read the realms file.
- */
-int read_realms_file(char *file)
-{
-	FILE	*fp;
-	char	buffer[256];
-	char	realm[32];
-	char	hostnm[128];
-	char	opts1[32], opts2[32];
-	char	*p;
-	int	lineno = 0;
-	REALM	*c;
-
-	realm_free(realms);
-	realms = NULL;
-
-	if ((fp = fopen(file, "r")) == NULL) {
-#if 1 /* For now - realms file is not obligatory */
-		return 0;
-#else
-		log(L_CONS|L_ERR, "cannot open %s", file);
-		return -1;
-#endif
-	}
-	while(fgets(buffer, 256, fp) != NULL) {
-		lineno++;
-		if (buffer[0] == '#' || buffer[0] == '\n')
-			continue;
-		opts1[0] = opts2[0] = 0;
-		if (sscanf(buffer, "%31s%127s%31s%31s",
-		     realm, hostnm, opts1, opts2) < 2) {
-			log(L_ERR, "%s[%d]: syntax error", file, lineno);
-			continue;
-		}
-		if ((c = malloc(sizeof(REALM))) == NULL) {
-			log(L_CONS|L_ERR, "%s[%d]: out of memory",
-				file, lineno);
-			return -1;
-		}
-
-		if ((p = strchr(hostnm, ':')) != NULL) {
-			*p++ = 0;
-			c->auth_port = atoi(p);
-			c->acct_port = c->auth_port + 1;
-		} else {
-			c->auth_port = auth_port;
-			c->acct_port = acct_port;
-		}
-		if (strcmp(hostnm, "LOCAL") != 0)
-			c->ipaddr = get_ipaddr(hostnm);
-		strNcpy(c->realm, realm, sizeof(c->realm));
-		strNcpy(c->server, hostnm, sizeof(c->server));
-		/* Yes we could do this more intelligently */
-                c->striprealm = strcmp(opts1, "nostrip") != 0 ||
-                                strcmp(opts2, "nostrip") != 0;
-                c->dohints    = strcmp(opts1, "hints") == 0 ||
-                                strcmp(opts2, "hints") == 0;
-		c->next = realms;
-		realms = c;
-	}
-	fclose(fp);
-
-	return 0;
-}
-
 /*
  *	Find a realm in the REALM list.
  */
@@ -2172,52 +1818,23 @@ static int checkdbm(char *users, char *ext)
 /*
  *	(Re-) read the configuration files.
  */
-int read_config_files()
-{
+int read_config_files(SQLSOCK *socket) {
 	char buffer[256];
 
-#ifndef USEMYSQL
-	pairlist_free(&users);
-	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_USERS);
-#endif
 	pairlist_free(&huntgroups);
 	pairlist_free(&hints);
 
-#ifndef USEMYSQL
-#if USE_DBM
-	if (!use_dbm && users &&
-		(checkdbm(users->name, ".dir") == 0 ||
-		checkdbm(users->name, ".db") == 0))
-			log(L_INFO|L_CONS, "DBM files found but no -b flag given - NOT using DBM");
-#endif
-
-	if (!use_dbm && (users = file_read(buffer, 1)) == NULL)
-		return -1;
-
-#endif
 	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_HUNTGROUPS);
 	huntgroups = file_read(buffer, 0);
 	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_HINTS);
 	hints      = file_read(buffer, 0);
-#ifdef USEMYSQL
-	if (mysql_read_realms(mysql_realm_table) < 0)
-		return -1;
-	if (mysql_read_naslist(mysql_nas_table) < 0)
-		return -1;
-	if (mysql_read_clients(mysql_nas_table) < 0)
-		return -1;
-#else
-	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_CLIENTS);
-	if (read_clients_file(buffer) < 0)
-		return -1;
-	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_NASLIST);
-	if (read_naslist_file(buffer) < 0)
-		return -1;
 
-	sprintf(buffer, "%.200s/%.50s", radius_dir, RADIUS_REALMS);
-	if (read_realms_file(buffer) < 0)
+	if (sql_read_realms(socket) < 0)
+		return -1;
+	if (sql_read_naslist(socket) < 0)
+		return -1;
+	if (sql_read_clients(socket) < 0)
 		return -1;
-#endif
 
 	if (cache_passwd) {
 		log(L_INFO, "HASH:  Reinitializing hash structures "
