@@ -83,6 +83,8 @@ static void proxy_cleanup(void)
 
 			if (a->data) free(a->data);
 			if (a->server_reply) pairfree(a->server_reply);
+			if (a->request) pairfree(a->request);
+			if (a->proxy_pairs) pairfree(a->proxy_pairs);
 			free(a);
 
 			continue;
@@ -552,8 +554,7 @@ int proxy_send(AUTH_REQ *authreq, int activefd)
  *	Returns:   0 proxy found
  *		  -1 error don't reply
  */
-int proxy_receive(AUTH_REQ *authreq, int activefd)
-{
+int proxy_receive(AUTH_REQ *authreq, int activefd) {
 	VALUE_PAIR	*vp, *last, *prev, *x;
 	VALUE_PAIR	*allowed_pairs;
 	AUTH_REQ	*oldreq, *lastreq;
