@@ -94,7 +94,7 @@ static AUTH_REQ		*first_request;
 extern int	errno;
 #endif
 
-typedef		int (*FUNP)(AUTH_REQ *, int);
+typedef		int (*FUNP)(AUTH_REQ *, int, SQLSOCK *socket);
 
 static int	config_init(void);
 static void	usage(void);
@@ -102,14 +102,14 @@ static void	usage(void);
 static void	sig_fatal (int);
 static void	sig_hup (int);
 
-static int	radrespond (AUTH_REQ *, int);
-static void	rad_spawn_child (AUTH_REQ *, int, FUNP);
+static int	radrespond (AUTH_REQ *, int, SQLSOCK *acctsock);
+static void	rad_spawn_child (AUTH_REQ *, int, FUNP, SQLSOCK *socket);
 
 /*
  *	Read config files.
  */
-static void reread_config(int reload)
-{
+static void reread_config(int reload) {
+	SQLSOCK	*socket;
 	int res = 0;
 	int pid = getpid();
 
@@ -119,30 +119,28 @@ static void reread_config(int reload)
 		log(L_INFO, "Reloading configuration files.");
 	}
 
-#ifdef USEMYSQL
-	if (mysql_start() != 0) {
-		log(L_ERR,"MYSQL Error: MySQL could not be initialized");
+
+	if (sql_init() != 0) {
+		log(L_ERR,"SQL Error: SQL connections could not be initialized");
 		res = -1;
 	}
-#endif
+
+	socket = sql_get_socket();
 
 	/* Initialize the dictionary */
-#ifdef USEMYSQL
-	if (mysql_dict_init() != 0)
+	if (sql_dict_init(socket) != 0)
 		res = -1;
-#else
-	if (dict_init(NULL) != 0)
-		res = -1;
-#endif
 
 	/* Initialize Configuration Values */
 	if (res == 0 && config_init() != 0)
 		res = -1;
 
 	/* Read users file etc. */
-	if (res == 0 && read_config_files() != 0)
+	if (res == 0 && read_config_files(socket) != 0)
 		res = -1;
 
+	sql_release_socket(socket);
+
 	if (res != 0) {
 		if (pid == radius_pid) {
 			log(L_ERR|L_CONS,
@@ -154,12 +152,6 @@ static void reread_config(int reload)
 		}
 		exit(1);
 	}
-#ifdef USEMYSQL
-	if (!mysql_keepopen) {
-		mysql_close(MyAuthSock);
-		MyAuthSock = NULL;
-	}
-#endif
 }
 
 
@@ -179,6 +171,7 @@ int main(int argc, char **argv)
 	int			status;
 	int			dontfork = 0;
 	int			radius_port = 0;
+	SQLSOCK			*acctsock;
 #ifdef RADIUS_PID
 	FILE			*fp;
 #endif
@@ -197,7 +190,7 @@ int main(int argc, char **argv)
 
 	debug_flag = 0;
 	spawn_flag = 1;
-	fork_auth = 0;
+	fork_auth = 1;
 	radacct_dir = RADACCT_DIR;
 	radlog_dir = RADLOG_DIR;
 	radius_dir = RADIUS_DIR;
@@ -276,16 +269,18 @@ int main(int argc, char **argv)
 		case 's':	/* Single process mode */
 			spawn_flag = 0;
 			break;
-		case 'n':  /* Fork individual authentication requests (normal) but MySQL code does not like this*/
+/* Hopfully fixed by adding sql pool
+		case 'n':
 			fork_auth = 1;
 			break;
+*/
 
 		case 'v':
 			version();
 			break;
 
 		case 'x':
-			debug_flag = 1;
+			debug_flag++;
 			break;
 		
 		case 'y':
@@ -302,6 +297,11 @@ int main(int argc, char **argv)
 		}
 	}
 
+	if ((sql = malloc(sizeof(SQL))) == NULL) {
+		log(L_ERR|L_CONS, "no memory");
+		exit(1);
+	}
+
 	/*
 	 *	Open Authentication socket.
 	 */
@@ -422,6 +422,10 @@ int main(int argc, char **argv)
 			log(L_INFO, "Ready to process requests.");
 		}
 		else {
+			acctsock = sql_create_socket();
+			acctsock->id = sql->config->max_sql_socks;
+			acctsock->in_use = getpid();
+			DEBUG2("SQL: Connected socket %d", sql->config->max_sql_socks);
 			close(sockfd);
 			sockfd = -1;
 		}
@@ -468,7 +472,7 @@ int main(int argc, char **argv)
 					ntohl(sin->sin_addr.s_addr),
 					ntohs(sin->sin_port),
 					recv_buffer, result);
-				radrespond(authreq, sockfd);
+				radrespond(authreq, sockfd, NULL);
 			}
 			else if (result < 0 && errno == EINTR) {
 				result = 0;
@@ -485,7 +489,7 @@ int main(int argc, char **argv)
 					ntohl(sin->sin_addr.s_addr),
 					ntohs(sin->sin_port),
 					recv_buffer, result);
-				radrespond(authreq, acctfd);
+				radrespond(authreq, acctfd, acctsock);
 			}
 			else if (result < 0 && errno == EINTR) {
 				result = 0;
@@ -510,12 +514,12 @@ int main(int argc, char **argv)
  *				Relay reply back to original NAS.
  *
  */
-int radrespond(AUTH_REQ *authreq, int activefd)
-{
-	int dospawn;
-	FUNP fun;
-	VALUE_PAIR *namepair;
-	int e;
+int radrespond(AUTH_REQ *authreq, int activefd, SQLSOCK *acctsock) {
+	int 		dospawn;
+	FUNP 		fun;
+	VALUE_PAIR 	*namepair;
+	int 		e;
+	SQLSOCK		*socket;
 
 	dospawn = 0;
 	fun = NULL;
@@ -556,10 +560,12 @@ int radrespond(AUTH_REQ *authreq, int activefd)
 
 	case PW_AUTHENTICATION_REQUEST:
 		dospawn = fork_auth;
+		socket = sql_get_socket();
 		fun = rad_authenticate;
 		break;
 	
 	case PW_ACCOUNTING_REQUEST:
+		socket = acctsock;
 		fun = rad_accounting;
 		break;
 	
@@ -583,9 +589,12 @@ int radrespond(AUTH_REQ *authreq, int activefd)
 
 	if (fun) {
 		if (dospawn)
-			rad_spawn_child(authreq, activefd, fun);
-		else
-			(*fun)(authreq, activefd);
+			rad_spawn_child(authreq, activefd, fun, socket);
+		else {
+			(*fun)(authreq, activefd, socket);
+			if (authreq->code == PW_AUTHENTICATION_REQUEST)
+				sql_release_socket(socket);
+		}
 	}
 
 	return 0;
@@ -599,8 +608,7 @@ int radrespond(AUTH_REQ *authreq, int activefd)
  *	is only one process responding to each request (duplicate
  *	requests are filtered out).
  */
-static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
-{
+static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun, SQLSOCK *socket) {
 	AUTH_REQ	*curreq;
 	AUTH_REQ	*prevreq;
 	UINT4		curtime;
@@ -650,6 +658,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 				"Dropping duplicate authentication packet"
 				" from client %s - ID: %d",
 				client_name(authreq->ipaddr), authreq->id);
+				sql_release_socket(socket);
 				pairfree(authreq->request);
 				free(authreq);
 				request_list_busy = 0;
@@ -675,6 +684,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 		} else {
 			if (curreq->timestamp + MAX_REQUEST_TIME <= curtime &&
 			    curreq->child_pid != -1) {
+				int	i;
 				/*
 				 *	This request seems to have hung -
 				 *	kill it
@@ -684,6 +694,9 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 					"Killing unresponsive child pid %d",
 								child_pid);
 				curreq->child_pid = -1;
+				for (i = 0; i < sql->config->max_sql_socks; i++)
+					if (child_pid == sql->socks[i]->in_use)
+						sql->socks[i]->in_use = 0;
 				kill(child_pid, SIGTERM);
 			}
 			prevreq = curreq;
@@ -732,7 +745,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 		 */
 		request_list_busy = 0;
 		signal(SIGCHLD, SIG_DFL);
-		(*fun)(authreq, activefd);
+		(*fun)(authreq, activefd, socket);
 
 		exit(0);
 	}
@@ -740,6 +753,7 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 	/*
 	 *	Register the Child
 	 */
+ 	socket->in_use = child_pid;
 	authreq->child_pid = child_pid;
 
 	request_list_busy = 0;
@@ -748,12 +762,11 @@ static void rad_spawn_child(AUTH_REQ *authreq, int activefd, FUNP fun)
 
 
 /*ARGSUSED*/
-void sig_cleanup(int sig)
-{
+void sig_cleanup(int sig) {
 	int		status;
         pid_t		pid;
 	AUTH_REQ	*curreq;
- 
+
 	/*
 	 *	request_list_busy is a lock on the request list
 	 */
@@ -786,6 +799,12 @@ void sig_cleanup(int sig)
 		curreq = first_request;
 		while (curreq != (AUTH_REQ *)NULL) {
 			if (curreq->child_pid == pid) {
+				int	i;
+				for (i = 0; i < sql->config->max_sql_socks; i++) {
+					if (curreq->child_pid == sql->socks[i]->in_use) {
+						sql_release_socket(sql->socks[i]);
+					}
+				}
 				curreq->child_pid = -1;
 				/*
 				 *	FIXME: UINT4 ?
@@ -803,13 +822,7 @@ void sig_cleanup(int sig)
  */
 static void usage(void)
 {
-	fprintf(stderr,
-#ifdef USE_DBM
-		"Usage: %s [-a acct_dir] [-d db_dir] [-l logdir] [-bcsxyz]\n",
-#else
-		"Usage: %s [-a acct_dir] [-d db_dir] [-l logdir] [-csxyz]\n",
-#endif
-		progname);
+	fprintf(stderr, "Usage: %s [-a acct_dir] [-d db_dir] [-l logdir] [-csxyz]\n", progname);
 	exit(1);
 }
 
