@@ -32,7 +32,8 @@
 
 #include "sysdep.h"
 #include "radius.h"
-#include "conf.h"
+
+#include "sql_module.h"
 
 /* Server data structures */
 
@@ -131,7 +132,6 @@ enum {
    PW_OPERATOR_GREATER_EQUAL,  /* >= */
 };
 
-
 typedef struct mysqlrec {
 	char                            AcctSessionId[SQLBIGREC];
         char                            UserName[SQLBIGREC];
@@ -209,14 +209,13 @@ extern int		log_auth_pass;
 extern int		auth_port;
 extern int		acct_port;
 
-#ifdef USEMYSQL
 NAS		*naslist;
 REALM		*realms;
 CLIENT		*clients;
 DICT_ATTR	*dictionary_attributes;
 DICT_VALUE	*dictionary_values;
 DICT_VENDOR	*dictionary_vendors;
-#endif
+SQL		*sql;
 
 
 /*
@@ -224,8 +223,8 @@ DICT_VENDOR	*dictionary_vendors;
  */
 
 /* acct.c */
-int		rad_accounting(AUTH_REQ *, int);
-int		rad_accounting_orig(AUTH_REQ *, int, char *);
+int		rad_accounting(AUTH_REQ *, int activefd, SQLSOCK *socket);
+int		rad_accounting_orig(AUTH_REQ *, int activefd, char *, SQLSOCK *socket);
 int		radzap(UINT4 nas, int port, char *user, time_t t);
 char		*uue(void *);
 int		rad_check_multi(char *name, VALUE_PAIR *request, int maxsimul);
@@ -282,7 +281,7 @@ int		calc_acctdigest(u_char *digest, AUTH_REQ *authreq);
 
 /* files.c */
 int		user_find(char *name, VALUE_PAIR *,
-				VALUE_PAIR **, VALUE_PAIR **);
+				VALUE_PAIR **, VALUE_PAIR **, SQLSOCK *socket);
 int		userparse(char *buffer, VALUE_PAIR **first_pair);
 void		presuf_setup(VALUE_PAIR *request_pairs);
 int		hints_setup(VALUE_PAIR *request_pairs);
@@ -296,7 +295,7 @@ char		*nas_name(UINT4 ipno);
 char		*nas_name2(AUTH_REQ *r);
 char		*auth_name(AUTH_REQ *authreq, int do_cid);
 int		read_naslist_file(char *);
-int		read_config_files(void);
+int		read_config_files(SQLSOCK *socket);
 int		presufcmp(VALUE_PAIR *check, char *name, char *rest, int rl);
 void		pairmove(VALUE_PAIR **to, VALUE_PAIR **from);
 void		pairmove2(VALUE_PAIR **to, VALUE_PAIR **from, int attr);
@@ -329,45 +328,20 @@ int proxy_receive(AUTH_REQ *authreq, int activefd);
 
 /* auth.c */
 int		rad_auth_init(AUTH_REQ *authreq, int activefd);
-int		rad_authenticate (AUTH_REQ *, int);
+int		rad_authenticate(AUTH_REQ *, int activefd, SQLSOCK *socket);
 
 /* exec.c */
 char		*radius_xlate(char *, VALUE_PAIR *req, VALUE_PAIR *reply);
 
 /* mysql.c */
-#ifdef USEMYSQL
-#define SQL_LOCK_LEN sizeof(MYSQLREC)
-#define MAX_TABLE_LEN 20
-#define MAX_AUTH_QUERY_LEN 256
-char mysql_server[40];
-char mysql_login[20];
-char mysql_password[20];
-char mysql_db[20];
-char mysql_acct_table[MAX_TABLE_LEN];
-char mysql_authcheck_table[MAX_TABLE_LEN];
-char mysql_authreply_table[MAX_TABLE_LEN];
-char mysql_groupcheck_table[MAX_TABLE_LEN];
-char mysql_groupreply_table[MAX_TABLE_LEN];
-char mysql_usergroup_table[MAX_TABLE_LEN];
-char mysql_realm_table[MAX_TABLE_LEN];
-char mysql_realmgroup_table[MAX_TABLE_LEN];
-char mysql_nas_table[MAX_TABLE_LEN];
-char mysql_dict_table[MAX_TABLE_LEN];
-int  mysql_keepopen;
-int  sensitiveusername;
-int  sqltrace; 
-MYSQL *MyAuthSock;
-MYSQL *MyAcctSock;
-MYSQL MyAuthConn;
-MYSQL MyAcctConn;
-int		mysql_start();
-int		mysql_save_acct(MYSQLREC *sqlrecord);
-int		mysql_userparse(VALUE_PAIR **first_pair, MYSQL_ROW row);
-int		mysql_checksocket(const char *facility);
-int		mysql_read_realms(char *realmtable);
-int		mysql_getvpdata(char *table, VALUE_PAIR **vp, char *user, int mode);
-int		mysql_check_multi(char *name, VALUE_PAIR *request, int maxsimul);
-int		mysql_read_naslist(char *nastable);
-int		mysql_read_clients(char *nastable);
-int		mysql_dict_init();
-#endif
+int		sql_init(void);
+SQLSOCK		*sql_get_socket(void);
+int		sql_release_socket(SQLSOCK *socket);
+int		sql_save_acct(SQLSOCK *socket, MYSQLREC *sqlrecord);
+int		sql_userparse(VALUE_PAIR **first_pair, SQL_ROW row);
+int		sql_read_realms(SQLSOCK *socket);
+int		sql_getvpdata(SQLSOCK *socket, char *table, VALUE_PAIR **vp, char *user, int mode);
+int		sql_check_multi(SQLSOCK *socket, char *name, VALUE_PAIR *request, int maxsimul);
+int		sql_read_naslist(SQLSOCK *socket);
+int		sql_read_clients(SQLSOCK *socket);
+int		sql_dict_init(SQLSOCK *socket);
