@@ -37,7 +37,7 @@ char version_sccsid[] =
  *  would like a range of versions allocated for your use.
  */
 
-#define		VERSION		"cistron-1.6.1 19-Oct-1999 +ICRADIUS 0.10"
+#define		VERSION		"cistron-1.6.2 19-Jan-2000 +ICRADIUS 0.11"
 
 /*
  *	Display the revision number for this program
@@ -104,9 +104,6 @@ void version(void)
 #endif
 #if defined(M_UNIX)
 	fprintf(stderr," M_UNIX");
-#endif
-#ifdef USEMYSQL
-	fprintf(stderr," USEMYSQL");
 #endif
 	fprintf(stderr,"\n");
 	exit(0);
